# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Biography(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Biography - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'biography': 'str',
            'interests': 'list[str]',
            'hobbies': 'list[str]',
            'spouse': 'str',
            'education': 'list[Education]'
        }

        self.attribute_map = {
            'biography': 'biography',
            'interests': 'interests',
            'hobbies': 'hobbies',
            'spouse': 'spouse',
            'education': 'education'
        }

        self._biography = None
        self._interests = None
        self._hobbies = None
        self._spouse = None
        self._education = None

    @property
    def biography(self):
        """
        Gets the biography of this Biography.
        Personal detailed description

        :return: The biography of this Biography.
        :rtype: str
        """
        return self._biography

    @biography.setter
    def biography(self, biography):
        """
        Sets the biography of this Biography.
        Personal detailed description

        :param biography: The biography of this Biography.
        :type: str
        """
        
        self._biography = biography

    @property
    def interests(self):
        """
        Gets the interests of this Biography.


        :return: The interests of this Biography.
        :rtype: list[str]
        """
        return self._interests

    @interests.setter
    def interests(self, interests):
        """
        Sets the interests of this Biography.


        :param interests: The interests of this Biography.
        :type: list[str]
        """
        
        self._interests = interests

    @property
    def hobbies(self):
        """
        Gets the hobbies of this Biography.


        :return: The hobbies of this Biography.
        :rtype: list[str]
        """
        return self._hobbies

    @hobbies.setter
    def hobbies(self, hobbies):
        """
        Sets the hobbies of this Biography.


        :param hobbies: The hobbies of this Biography.
        :type: list[str]
        """
        
        self._hobbies = hobbies

    @property
    def spouse(self):
        """
        Gets the spouse of this Biography.


        :return: The spouse of this Biography.
        :rtype: str
        """
        return self._spouse

    @spouse.setter
    def spouse(self, spouse):
        """
        Sets the spouse of this Biography.


        :param spouse: The spouse of this Biography.
        :type: str
        """
        
        self._spouse = spouse

    @property
    def education(self):
        """
        Gets the education of this Biography.
        User education details

        :return: The education of this Biography.
        :rtype: list[Education]
        """
        return self._education

    @education.setter
    def education(self, education):
        """
        Sets the education of this Biography.
        User education details

        :param education: The education of this Biography.
        :type: list[Education]
        """
        
        self._education = education

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

