# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class EmergencyCallFlow(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EmergencyCallFlow - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'emergency_flow': 'DomainEntityRef',
            'ivrs': 'list[DomainEntityRef]'
        }

        self.attribute_map = {
            'emergency_flow': 'emergencyFlow',
            'ivrs': 'ivrs'
        }

        self._emergency_flow = None
        self._ivrs = None

    @property
    def emergency_flow(self):
        """
        Gets the emergency_flow of this EmergencyCallFlow.
        The call flow to execute in an emergency.

        :return: The emergency_flow of this EmergencyCallFlow.
        :rtype: DomainEntityRef
        """
        return self._emergency_flow

    @emergency_flow.setter
    def emergency_flow(self, emergency_flow):
        """
        Sets the emergency_flow of this EmergencyCallFlow.
        The call flow to execute in an emergency.

        :param emergency_flow: The emergency_flow of this EmergencyCallFlow.
        :type: DomainEntityRef
        """
        
        self._emergency_flow = emergency_flow

    @property
    def ivrs(self):
        """
        Gets the ivrs of this EmergencyCallFlow.
        The IVR(s) to route to the call flow during an emergency.

        :return: The ivrs of this EmergencyCallFlow.
        :rtype: list[DomainEntityRef]
        """
        return self._ivrs

    @ivrs.setter
    def ivrs(self, ivrs):
        """
        Sets the ivrs of this EmergencyCallFlow.
        The IVR(s) to route to the call flow during an emergency.

        :param ivrs: The ivrs of this EmergencyCallFlow.
        :type: list[DomainEntityRef]
        """
        
        self._ivrs = ivrs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

