# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class LexBotAlias(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LexBotAlias - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'bot': 'LexBot',
            'bot_version': 'str',
            'status': 'str',
            'failure_reason': 'str',
            'language': 'str',
            'intents': 'list[LexIntent]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'bot': 'bot',
            'bot_version': 'botVersion',
            'status': 'status',
            'failure_reason': 'failureReason',
            'language': 'language',
            'intents': 'intents',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._bot = None
        self._bot_version = None
        self._status = None
        self._failure_reason = None
        self._language = None
        self._intents = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this LexBotAlias.
        The globally unique identifier for the object.

        :return: The id of this LexBotAlias.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LexBotAlias.
        The globally unique identifier for the object.

        :param id: The id of this LexBotAlias.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this LexBotAlias.


        :return: The name of this LexBotAlias.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LexBotAlias.


        :param name: The name of this LexBotAlias.
        :type: str
        """
        
        self._name = name

    @property
    def bot(self):
        """
        Gets the bot of this LexBotAlias.
        The Lex bot this is an alias for

        :return: The bot of this LexBotAlias.
        :rtype: LexBot
        """
        return self._bot

    @bot.setter
    def bot(self, bot):
        """
        Sets the bot of this LexBotAlias.
        The Lex bot this is an alias for

        :param bot: The bot of this LexBotAlias.
        :type: LexBot
        """
        
        self._bot = bot

    @property
    def bot_version(self):
        """
        Gets the bot_version of this LexBotAlias.
        The version of the Lex bot this alias points at

        :return: The bot_version of this LexBotAlias.
        :rtype: str
        """
        return self._bot_version

    @bot_version.setter
    def bot_version(self, bot_version):
        """
        Sets the bot_version of this LexBotAlias.
        The version of the Lex bot this alias points at

        :param bot_version: The bot_version of this LexBotAlias.
        :type: str
        """
        
        self._bot_version = bot_version

    @property
    def status(self):
        """
        Gets the status of this LexBotAlias.
        The status of the Lex bot alias

        :return: The status of this LexBotAlias.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this LexBotAlias.
        The status of the Lex bot alias

        :param status: The status of this LexBotAlias.
        :type: str
        """
        allowed_values = ["BUILDING", "READY", "FAILED", "NOT_BUILT"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def failure_reason(self):
        """
        Gets the failure_reason of this LexBotAlias.
        If the status is FAILED, Amazon Lex explains why it failed to build the bot

        :return: The failure_reason of this LexBotAlias.
        :rtype: str
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """
        Sets the failure_reason of this LexBotAlias.
        If the status is FAILED, Amazon Lex explains why it failed to build the bot

        :param failure_reason: The failure_reason of this LexBotAlias.
        :type: str
        """
        
        self._failure_reason = failure_reason

    @property
    def language(self):
        """
        Gets the language of this LexBotAlias.
        The target language of the Lex bot

        :return: The language of this LexBotAlias.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this LexBotAlias.
        The target language of the Lex bot

        :param language: The language of this LexBotAlias.
        :type: str
        """
        allowed_values = ["en-US"]
        if language.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for language -> " + language)
            self._language = "outdated_sdk_version"
        else:
            self._language = language

    @property
    def intents(self):
        """
        Gets the intents of this LexBotAlias.
        An array of Intents associated with this bot alias

        :return: The intents of this LexBotAlias.
        :rtype: list[LexIntent]
        """
        return self._intents

    @intents.setter
    def intents(self, intents):
        """
        Sets the intents of this LexBotAlias.
        An array of Intents associated with this bot alias

        :param intents: The intents of this LexBotAlias.
        :type: list[LexIntent]
        """
        
        self._intents = intents

    @property
    def self_uri(self):
        """
        Gets the self_uri of this LexBotAlias.
        The URI for this object

        :return: The self_uri of this LexBotAlias.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this LexBotAlias.
        The URI for this object

        :param self_uri: The self_uri of this LexBotAlias.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

