# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ActionInput(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ActionInput - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'input_schema': 'JsonSchemaDocument',
            'input_schema_flattened': 'JsonSchemaDocument',
            'input_schema_uri': 'str'
        }

        self.attribute_map = {
            'input_schema': 'inputSchema',
            'input_schema_flattened': 'inputSchemaFlattened',
            'input_schema_uri': 'inputSchemaUri'
        }

        self._input_schema = None
        self._input_schema_flattened = None
        self._input_schema_uri = None

    @property
    def input_schema(self):
        """
        Gets the input_schema of this ActionInput.
        JSON Schema that defines the body of the request that the client (edge/architect/postman) is sending to the service, on the /execute path. If the 'flatten' query parameter is omitted or false, this field will be returned. Either inputSchema or inputSchemaFlattened will be returned, not both.

        :return: The input_schema of this ActionInput.
        :rtype: JsonSchemaDocument
        """
        return self._input_schema

    @input_schema.setter
    def input_schema(self, input_schema):
        """
        Sets the input_schema of this ActionInput.
        JSON Schema that defines the body of the request that the client (edge/architect/postman) is sending to the service, on the /execute path. If the 'flatten' query parameter is omitted or false, this field will be returned. Either inputSchema or inputSchemaFlattened will be returned, not both.

        :param input_schema: The input_schema of this ActionInput.
        :type: JsonSchemaDocument
        """
        
        self._input_schema = input_schema

    @property
    def input_schema_flattened(self):
        """
        Gets the input_schema_flattened of this ActionInput.
        JSON Schema that defines the body of the request that the client (edge/architect/postman) is sending to the service, on the /execute path. The schema is transformed based on Architect's flattened format. If the 'flatten' query parameter is supplied as true, this field will be returned. Either inputSchema or inputSchemaFlattened will be returned, not both.

        :return: The input_schema_flattened of this ActionInput.
        :rtype: JsonSchemaDocument
        """
        return self._input_schema_flattened

    @input_schema_flattened.setter
    def input_schema_flattened(self, input_schema_flattened):
        """
        Sets the input_schema_flattened of this ActionInput.
        JSON Schema that defines the body of the request that the client (edge/architect/postman) is sending to the service, on the /execute path. The schema is transformed based on Architect's flattened format. If the 'flatten' query parameter is supplied as true, this field will be returned. Either inputSchema or inputSchemaFlattened will be returned, not both.

        :param input_schema_flattened: The input_schema_flattened of this ActionInput.
        :type: JsonSchemaDocument
        """
        
        self._input_schema_flattened = input_schema_flattened

    @property
    def input_schema_uri(self):
        """
        Gets the input_schema_uri of this ActionInput.
        The URI of the input schema

        :return: The input_schema_uri of this ActionInput.
        :rtype: str
        """
        return self._input_schema_uri

    @input_schema_uri.setter
    def input_schema_uri(self, input_schema_uri):
        """
        Sets the input_schema_uri of this ActionInput.
        The URI of the input schema

        :param input_schema_uri: The input_schema_uri of this ActionInput.
        :type: str
        """
        
        self._input_schema_uri = input_schema_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

