# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SurveyScoringSet(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SurveyScoringSet - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'total_score': 'float',
            'nps_score': 'int',
            'question_group_scores': 'list[SurveyQuestionGroupScore]'
        }

        self.attribute_map = {
            'total_score': 'totalScore',
            'nps_score': 'npsScore',
            'question_group_scores': 'questionGroupScores'
        }

        self._total_score = None
        self._nps_score = None
        self._question_group_scores = None

    @property
    def total_score(self):
        """
        Gets the total_score of this SurveyScoringSet.


        :return: The total_score of this SurveyScoringSet.
        :rtype: float
        """
        return self._total_score

    @total_score.setter
    def total_score(self, total_score):
        """
        Sets the total_score of this SurveyScoringSet.


        :param total_score: The total_score of this SurveyScoringSet.
        :type: float
        """
        
        self._total_score = total_score

    @property
    def nps_score(self):
        """
        Gets the nps_score of this SurveyScoringSet.


        :return: The nps_score of this SurveyScoringSet.
        :rtype: int
        """
        return self._nps_score

    @nps_score.setter
    def nps_score(self, nps_score):
        """
        Sets the nps_score of this SurveyScoringSet.


        :param nps_score: The nps_score of this SurveyScoringSet.
        :type: int
        """
        
        self._nps_score = nps_score

    @property
    def question_group_scores(self):
        """
        Gets the question_group_scores of this SurveyScoringSet.


        :return: The question_group_scores of this SurveyScoringSet.
        :rtype: list[SurveyQuestionGroupScore]
        """
        return self._question_group_scores

    @question_group_scores.setter
    def question_group_scores(self, question_group_scores):
        """
        Sets the question_group_scores of this SurveyScoringSet.


        :param question_group_scores: The question_group_scores of this SurveyScoringSet.
        :type: list[SurveyQuestionGroupScore]
        """
        
        self._question_group_scores = question_group_scores

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

