# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TwitterIntegrationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TwitterIntegrationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'access_token_key': 'str',
            'access_token_secret': 'str',
            'consumer_key': 'str',
            'consumer_secret': 'str',
            'tier': 'str',
            'env_name': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'access_token_key': 'accessTokenKey',
            'access_token_secret': 'accessTokenSecret',
            'consumer_key': 'consumerKey',
            'consumer_secret': 'consumerSecret',
            'tier': 'tier',
            'env_name': 'envName',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._access_token_key = None
        self._access_token_secret = None
        self._consumer_key = None
        self._consumer_secret = None
        self._tier = None
        self._env_name = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this TwitterIntegrationRequest.
        The globally unique identifier for the object.

        :return: The id of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TwitterIntegrationRequest.
        The globally unique identifier for the object.

        :param id: The id of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this TwitterIntegrationRequest.
        The name of the Twitter Integration

        :return: The name of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TwitterIntegrationRequest.
        The name of the Twitter Integration

        :param name: The name of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._name = name

    @property
    def access_token_key(self):
        """
        Gets the access_token_key of this TwitterIntegrationRequest.
        The Access Token Key from Twitter messenger

        :return: The access_token_key of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._access_token_key

    @access_token_key.setter
    def access_token_key(self, access_token_key):
        """
        Sets the access_token_key of this TwitterIntegrationRequest.
        The Access Token Key from Twitter messenger

        :param access_token_key: The access_token_key of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._access_token_key = access_token_key

    @property
    def access_token_secret(self):
        """
        Gets the access_token_secret of this TwitterIntegrationRequest.
        The Access Token Secret from Twitter messenger

        :return: The access_token_secret of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._access_token_secret

    @access_token_secret.setter
    def access_token_secret(self, access_token_secret):
        """
        Sets the access_token_secret of this TwitterIntegrationRequest.
        The Access Token Secret from Twitter messenger

        :param access_token_secret: The access_token_secret of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._access_token_secret = access_token_secret

    @property
    def consumer_key(self):
        """
        Gets the consumer_key of this TwitterIntegrationRequest.
        The Consumer Key from Twitter messenger

        :return: The consumer_key of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._consumer_key

    @consumer_key.setter
    def consumer_key(self, consumer_key):
        """
        Sets the consumer_key of this TwitterIntegrationRequest.
        The Consumer Key from Twitter messenger

        :param consumer_key: The consumer_key of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._consumer_key = consumer_key

    @property
    def consumer_secret(self):
        """
        Gets the consumer_secret of this TwitterIntegrationRequest.
        The Consumer Secret from Twitter messenger

        :return: The consumer_secret of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._consumer_secret

    @consumer_secret.setter
    def consumer_secret(self, consumer_secret):
        """
        Sets the consumer_secret of this TwitterIntegrationRequest.
        The Consumer Secret from Twitter messenger

        :param consumer_secret: The consumer_secret of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._consumer_secret = consumer_secret

    @property
    def tier(self):
        """
        Gets the tier of this TwitterIntegrationRequest.
        The type of twitter account to be used for the integration

        :return: The tier of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._tier

    @tier.setter
    def tier(self, tier):
        """
        Sets the tier of this TwitterIntegrationRequest.
        The type of twitter account to be used for the integration

        :param tier: The tier of this TwitterIntegrationRequest.
        :type: str
        """
        allowed_values = ["premium", "enterprise"]
        if tier.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for tier -> " + tier)
            self._tier = "outdated_sdk_version"
        else:
            self._tier = tier

    @property
    def env_name(self):
        """
        Gets the env_name of this TwitterIntegrationRequest.
        The Twitter environment name, e.g.: env-beta (required for premium tier)

        :return: The env_name of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._env_name

    @env_name.setter
    def env_name(self, env_name):
        """
        Sets the env_name of this TwitterIntegrationRequest.
        The Twitter environment name, e.g.: env-beta (required for premium tier)

        :param env_name: The env_name of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._env_name = env_name

    @property
    def self_uri(self):
        """
        Gets the self_uri of this TwitterIntegrationRequest.
        The URI for this object

        :return: The self_uri of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this TwitterIntegrationRequest.
        The URI for this object

        :param self_uri: The self_uri of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

