# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BatchDownloadJobResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BatchDownloadJobResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'conversation_id': 'str',
            'recording_id': 'str',
            'result_url': 'str',
            'content_type': 'str',
            'error_msg': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'conversation_id': 'conversationId',
            'recording_id': 'recordingId',
            'result_url': 'resultUrl',
            'content_type': 'contentType',
            'error_msg': 'errorMsg',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._conversation_id = None
        self._recording_id = None
        self._result_url = None
        self._content_type = None
        self._error_msg = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this BatchDownloadJobResult.
        The globally unique identifier for the object.

        :return: The id of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BatchDownloadJobResult.
        The globally unique identifier for the object.

        :param id: The id of this BatchDownloadJobResult.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this BatchDownloadJobResult.


        :return: The name of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BatchDownloadJobResult.


        :param name: The name of this BatchDownloadJobResult.
        :type: str
        """
        
        self._name = name

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this BatchDownloadJobResult.
        Conversation id of the result

        :return: The conversation_id of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this BatchDownloadJobResult.
        Conversation id of the result

        :param conversation_id: The conversation_id of this BatchDownloadJobResult.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def recording_id(self):
        """
        Gets the recording_id of this BatchDownloadJobResult.
        Recording id of the result

        :return: The recording_id of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._recording_id

    @recording_id.setter
    def recording_id(self, recording_id):
        """
        Sets the recording_id of this BatchDownloadJobResult.
        Recording id of the result

        :param recording_id: The recording_id of this BatchDownloadJobResult.
        :type: str
        """
        
        self._recording_id = recording_id

    @property
    def result_url(self):
        """
        Gets the result_url of this BatchDownloadJobResult.
        URL of results... HTTP GET from this location to download results for this item

        :return: The result_url of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._result_url

    @result_url.setter
    def result_url(self, result_url):
        """
        Sets the result_url of this BatchDownloadJobResult.
        URL of results... HTTP GET from this location to download results for this item

        :param result_url: The result_url of this BatchDownloadJobResult.
        :type: str
        """
        
        self._result_url = result_url

    @property
    def content_type(self):
        """
        Gets the content_type of this BatchDownloadJobResult.
        Content type of this result

        :return: The content_type of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this BatchDownloadJobResult.
        Content type of this result

        :param content_type: The content_type of this BatchDownloadJobResult.
        :type: str
        """
        
        self._content_type = content_type

    @property
    def error_msg(self):
        """
        Gets the error_msg of this BatchDownloadJobResult.
        An error message, in case of failed processing will indicate the cause of the failure

        :return: The error_msg of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        """
        Sets the error_msg of this BatchDownloadJobResult.
        An error message, in case of failed processing will indicate the cause of the failure

        :param error_msg: The error_msg of this BatchDownloadJobResult.
        :type: str
        """
        
        self._error_msg = error_msg

    @property
    def self_uri(self):
        """
        Gets the self_uri of this BatchDownloadJobResult.
        The URI for this object

        :return: The self_uri of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this BatchDownloadJobResult.
        The URI for this object

        :param self_uri: The self_uri of this BatchDownloadJobResult.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

