# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScreenRecordingSession(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScreenRecordingSession - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'user': 'User',
            'communication_id': 'str',
            'conversation': 'Conversation',
            'start_time': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'user': 'user',
            'communication_id': 'communicationId',
            'conversation': 'conversation',
            'start_time': 'startTime',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._user = None
        self._communication_id = None
        self._conversation = None
        self._start_time = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ScreenRecordingSession.
        The globally unique identifier for the object.

        :return: The id of this ScreenRecordingSession.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScreenRecordingSession.
        The globally unique identifier for the object.

        :param id: The id of this ScreenRecordingSession.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ScreenRecordingSession.


        :return: The name of this ScreenRecordingSession.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScreenRecordingSession.


        :param name: The name of this ScreenRecordingSession.
        :type: str
        """
        
        self._name = name

    @property
    def user(self):
        """
        Gets the user of this ScreenRecordingSession.


        :return: The user of this ScreenRecordingSession.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ScreenRecordingSession.


        :param user: The user of this ScreenRecordingSession.
        :type: User
        """
        
        self._user = user

    @property
    def communication_id(self):
        """
        Gets the communication_id of this ScreenRecordingSession.
        The id of the communication that is being recorded on the conversation

        :return: The communication_id of this ScreenRecordingSession.
        :rtype: str
        """
        return self._communication_id

    @communication_id.setter
    def communication_id(self, communication_id):
        """
        Sets the communication_id of this ScreenRecordingSession.
        The id of the communication that is being recorded on the conversation

        :param communication_id: The communication_id of this ScreenRecordingSession.
        :type: str
        """
        
        self._communication_id = communication_id

    @property
    def conversation(self):
        """
        Gets the conversation of this ScreenRecordingSession.


        :return: The conversation of this ScreenRecordingSession.
        :rtype: Conversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this ScreenRecordingSession.


        :param conversation: The conversation of this ScreenRecordingSession.
        :type: Conversation
        """
        
        self._conversation = conversation

    @property
    def start_time(self):
        """
        Gets the start_time of this ScreenRecordingSession.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_time of this ScreenRecordingSession.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ScreenRecordingSession.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_time: The start_time of this ScreenRecordingSession.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ScreenRecordingSession.
        The URI for this object

        :return: The self_uri of this ScreenRecordingSession.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ScreenRecordingSession.
        The URI for this object

        :param self_uri: The self_uri of this ScreenRecordingSession.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

